@@ -5,20 +5,21 @@
 #'
 #' @section Design Steps:
 #' \describe{
-#'   \item{\code{\link{declare_population}}}{Population step}
-#'   \item{\code{\link{declare_potential_outcomes}}}{Potential outcomes step}
-#'   \item{\code{\link{declare_sampling}}}{Sampling step}
-#'   \item{\code{\link{declare_assignment}}}{Assignment step}
-#'   \item{\code{\link{reveal_outcomes}}}{Reveal outcomes step}
-#'   \item{\code{\link{declare_estimand}}}{Estimand step}
-#'   \item{\code{\link{declare_estimator}}}{Estimator step}
+#'   \item{\code{\link{declare_model}}}{Model step}
+#'   \item{\code{\link{declare_inquiry}}}{Inquiry step}
+#'   \item{\code{\link{declare_sampling}}}{Data strategy step (sampling)}
+#'   \item{\code{\link{declare_assignment}}}{Data strategy step (assignment)}
+#'   \item{\code{\link{declare_measurement}}}{Data strategy step (measurement)}
+#'   \item{\code{\link{declare_estimator}}}{Answer strategy step (Estimator)}
+#'   \item{\code{\link{declare_test}}}{Answer strategy step (Testing function)}
 #' }
 #'
 #' @section Design Objects:
 #' \describe{
 #'   \item{+}{Add steps to create a design}
-#'   \item{\code{\link{draw_data}}}{Simulate the DGP}
-#'   \item{\code{\link{run_design}}}{Simulate the DGP with estimands/estimators}
+#'   \item{\code{\link{redesign}}}{Change design parameters}
+#'   \item{\code{\link{draw_data}}}{Draw a simulated dataset}
+#'   \item{\code{\link{run_design}}}{Draw one set of inquiry values and estimates}
 #'   \item{\code{\link{diagnose_design}}}{Diagnose a design}
 #'   \item{\code{\link{cite_design}}}{Cite a design}
 #' }
@@ -44,12 +45,4 @@
 #' @name DeclareDesign
 NULL
 
-
-.onLoad <- function(libname, pkgname) {
-  repos <- getOption("repos")
-  repos["declaredesign"] <- "https://declaredesign.github.io"
-  options(repos = repos)
-  invisible(repos)
-}
-
-utils::globalVariables(c("Y", "Z", "N", "conf.low", "conf.high", "estimate", "estimand", "p.value", "std.error"))
+utils::globalVariables(c("Y", "Z", "S", "N", "conf.low", "conf.high", "estimate", "inquiry", "p.value", "std.error"))
