@@ -8,3 +8,10 @@
 #' @keywords internal
 NULL
 
+estimand_handler <- function(...){
+  .Deprecated(new = "inquiry_handler")
+}
+
+compare_design_estimands <- function(...){
+  .Deprecated(new = "compare_design_inquiries")
+}
\ No newline at end of file
