@@ -9,7 +9,7 @@ test_that("use of randomizr works", {
   
   dat <- draw_data(design)
   
-  assgn1 <- declare_assignment(legacy = FALSE, Z = complete_ra(N = N, m = 10))
+  assgn1 <- declare_assignment(Z = complete_ra(N = N, m = 10))
   
   expect_equal(sum(assgn1(dat)$Z), 10)
   
@@ -17,9 +17,9 @@ test_that("use of randomizr works", {
 
 
 test_that("legacy warnings", {
-  expect_error(declare_assignment(legacy = FALSE, m = 50), "Z = conduct_ra\\(N = N, m = 50\\)")
-  expect_error(declare_assignment(legacy = FALSE, m = 50, assignment_variable = "D"), "D = conduct_ra\\(N = N, m = 50\\)")
-  expect_silent(declare_assignment(legacy = FALSE, Z = complete_ra(N = N, m = 20)))
+  expect_error(declare_assignment(m = 50), "Z = conduct_ra\\(N = N, m = 50\\)")
+  expect_error(declare_assignment(m = 50, assignment_variable = "D"), "D = conduct_ra\\(N = N, m = 50\\)")
+  expect_silent(declare_assignment(Z = complete_ra(N = N, m = 20)))
 })
 
 
@@ -34,29 +34,24 @@ expect_equal(dim(draw_data(des1)), c(10, 1))
 expect_equal(dim(draw_data(des2)), c(10, 3))
 })
 
-
-declare_model(N = 10) + declare_assignment(prob = 0.5, assignment_variable = A)
-declare_model(N = 10) + declare_assignment(prob = 0.5, assignment_variable = "A")
-
-
 context("Assignment and probability functions")
 
 test_that("randomizr works through declare_assignment", {
   df <- data.frame(ID = 1:10, blocks = rep(c("A", "B"), 5, 5))
   
-  f_1 <- declare_assignment()
+  f_1 <- declare_assignment(legacy = TRUE)
   expect_equal(sum(f_1(df)$Z), 5)
   
-  f_1 <- declare_assignment(m = 5)
+  f_1 <- declare_assignment(m = 5, legacy = TRUE)
   expect_equal(sum(f_1(df)$Z), 5)
   
-  f_1 <- declare_assignment(num_arms = 2)
+  f_1 <- declare_assignment(num_arms = 2, legacy = TRUE)
   expect_equal(sum(f_1(df)$Z == "T1"), 5)
   
-  f_1 <- declare_assignment(num_arms = 3)
+  f_1 <- declare_assignment(num_arms = 3, legacy = TRUE)
   expect_true(all(table(f_1(df)$Z) >= 3))
   
-  f_1 <- declare_assignment(blocks = blocks)
+  f_1 <- declare_assignment(blocks = blocks, legacy = TRUE)
   expect_true(all.equal(
     unclass(xtabs(~blocks + Z, f_1(df))),
     matrix(c(3, 2, 3, 2), 2, 2), # slight bug in the blocks above with rep(AB,5,5) => ABABA x 2
@@ -67,7 +62,7 @@ test_that("randomizr works through declare_assignment", {
   # what about inside a function?
   
   new_fun <- function(num_arms) {
-    f_1 <- declare_assignment(num_arms = num_arms)
+    f_1 <- declare_assignment(num_arms = num_arms, legacy = TRUE)
     f_1(df)
   }
   new_fun(3)
@@ -94,7 +89,7 @@ test_that("test assignment and probability functions", {
     individuals = modify_level(ideo_3 = draw_ideo(N), by = "villages")
   )
   
-  sampling <- declare_sampling(n = 10, clusters = villages)
+  sampling <- declare_sampling(n = 10, clusters = villages, legacy = TRUE)
   
   potential_outcomes <- declare_potential_outcomes(
     formula = Y ~ 5 + .5 * (Z == 1) + .9 * (Z == 2) + .2 * Z * elevation + noise,
@@ -115,49 +110,53 @@ test_that("test assignment and probability functions", {
   
   
   # Complete Random Assignment assignments
-  assignment_0 <- declare_assignment() %>% expect_assignment() # blug
-  assignment_1 <- declare_assignment(conditions = c(0, 1)) %>% expect_assignment()
-  assignment_2 <- declare_assignment(m = 60, conditions = c(0, 1)) %>% expect_assignment()
-  assignment_3 <- declare_assignment(m_each = c(20, 30, 50)) %>% expect_assignment()
-  assignment_4 <- declare_assignment(m_each = c(20, 80), conditions = c(0, 1)) %>% expect_assignment()
-  assignment_5 <- declare_assignment(prob_each = c(.2, .3, .5)) %>% expect_assignment()
+  assignment_0 <- declare_assignment(legacy = TRUE, ) %>% expect_assignment() # blug
+  assignment_1 <- declare_assignment(legacy = TRUE, conditions = c(0, 1)) %>% expect_assignment()
+  assignment_2 <- declare_assignment(legacy = TRUE, m = 60, conditions = c(0, 1)) %>% expect_assignment()
+  assignment_3 <- declare_assignment(legacy = TRUE, m_each = c(20, 30, 50)) %>% expect_assignment()
+  assignment_4 <- declare_assignment(legacy = TRUE, m_each = c(20, 80), conditions = c(0, 1)) %>% expect_assignment()
+  assignment_5 <- declare_assignment(legacy = TRUE, prob_each = c(.2, .3, .5)) %>% expect_assignment()
   
   # Blocked assignments
-  assignment_6 <- declare_assignment(blocks = ideo_3) %>% expect_assignment()
-  assignment_7 <- declare_assignment(blocks = ideo_3, prob_each = c(.3, .6, .1)) %>% expect_assignment()
-  assignment_8 <- declare_assignment(blocks = ideo_3, conditions = c(0, 1)) %>% expect_assignment()
+  assignment_6 <- declare_assignment(legacy = TRUE, blocks = ideo_3) %>% expect_assignment()
+  assignment_7 <- declare_assignment(legacy = TRUE, blocks = ideo_3, prob_each = c(.3, .6, .1)) %>% expect_assignment()
+  assignment_8 <- declare_assignment(legacy = TRUE, blocks = ideo_3, conditions = c(0, 1)) %>% expect_assignment()
   
   assignment_9 <- declare_assignment(
     blocks = ideo_3,
     conditions = c(0, 1),
-    block_m = c(10, 10, 10)
+    block_m = c(10, 10, 10),
+    legacy = TRUE
   ) %>% expect_assignment()
   
   
   # Clustered assignments
-  assignment_10 <- declare_assignment(clusters = villages) %>% expect_assignment()
-  assignment_11 <- declare_assignment(clusters = villages, conditions = c(0, 1)) %>% expect_assignment()
-  assignment_12 <- declare_assignment(clusters = villages, prob_each = c(.1, .3, .6)) %>% expect_assignment()
+  assignment_10 <- declare_assignment(legacy = TRUE, clusters = villages) %>% expect_assignment()
+  assignment_11 <- declare_assignment(legacy = TRUE, clusters = villages, conditions = c(0, 1)) %>% expect_assignment()
+  assignment_12 <- declare_assignment(legacy = TRUE, clusters = villages, prob_each = c(.1, .3, .6)) %>% expect_assignment()
   
   # Blocked and Clustered assignments
   assignment_13 <- declare_assignment(
     clusters = villages,
-    blocks = high_elevation
+    blocks = high_elevation,
+    legacy = TRUE
   ) %>% expect_assignment()
   
   assignment_14 <- declare_assignment(
     clusters = villages,
-    blocks = high_elevation, conditions = c(0, 1)
+    blocks = high_elevation, conditions = c(0, 1),
+    legacy = TRUE
   ) %>% expect_assignment()
   assignment_15 <- declare_assignment(
     clusters = villages,
-    blocks = high_elevation, prob_each = c(.1, .3, .6)
+    blocks = high_elevation, prob_each = c(.1, .3, .6),
+    legacy = TRUE
   ) %>% expect_assignment()
   
 })
 
 test_that("more than 1 assignment", {
-  assn <- declare_assignment(assignment_variable = P:Q)
+  assn <- declare_assignment(legacy = TRUE, assignment_variable = P:Q)
   
   out <- assn(sleep)
   
@@ -166,19 +165,19 @@ test_that("more than 1 assignment", {
 
 
 test_that("declare_assignment expected failures via validation fn", {
-  expect_true(is.function(declare_assignment()))
+  expect_true(is.function(declare_assignment(legacy = TRUE)))
   
-  expect_error(declare_assignment(blocks = "character"), "blocks")
+  expect_error(declare_assignment(legacy = TRUE, blocks = "character"), "blocks")
   
-  expect_error(declare_assignment(clusters = "character"), "clusters")
+  expect_error(declare_assignment(legacy = TRUE, clusters = "character"), "clusters")
   
-  expect_error(declare_assignment(assignment_variable = NULL), "assignment_variable")
+  expect_error(declare_assignment(legacy = TRUE, assignment_variable = NULL), "assignment_variable")
 })
 
 
 test_that("can append probabilities matrix", {
   pop <- declare_population(N = 10)
-  assignment <- declare_assignment(m = 5, append_probabilities_matrix = TRUE)
+  assignment <- declare_assignment(legacy = TRUE, m = 5, append_probabilities_matrix = TRUE)
   dat <- draw_data(pop + assignment)
   
   expect_true("Z_prob_0" %in% colnames(dat))
@@ -193,7 +192,7 @@ test_that("can append probabiliies matrix with blocks from data", {
                        indiv = add_level(N = 50,
                                          e = rnorm(N, 0, 5))) +
     declare_assignment(blocks = block, block_prob = c(.5, .7, .9), 
-                       append_probabilities_matrix = TRUE) 
+                       append_probabilities_matrix = TRUE, legacy = TRUE) 
   
   df <- draw_data(design)
   
