@@ -9,7 +9,7 @@ test_that("send inquiry to estimator works", {
       Y_Z_1 = noise + rnorm(N, mean = 2, sd = 2)
     )
 
-  my_assignment <- declare_assignment(legacy = FALSE, Z = complete_ra(N, m = 25))
+  my_assignment <- declare_assignment(Z = complete_ra(N, m = 25))
 
   pate <- declare_inquiry(mean(Y_Z_1 - Y_Z_0), label = "pate")
 
