@@ -10,7 +10,7 @@ test_that("Factorial", {
     Y_Z_T4 = noise + 0.6
   )
 
-  my_assignment <- declare_assignment(legacy = FALSE, Z = complete_ra(N, num_arms = 4))
+  my_assignment <- declare_assignment(Z = complete_ra(N, num_arms = 4))
 
   my_inquiry <- declare_inquiry(interaction = mean(Y_Z_T4 - Y_Z_T3) - mean(Y_Z_T2 - Y_Z_T1))
 
@@ -34,7 +34,7 @@ test_that("Factorial", {
     my_estimator
 
   expect_equal(my_design %>% draw_data() %>% nrow(), 2000)
-  expect_equal(my_design %>% run_design() %>% names(), c("inquiry_label", "estimand", "estimator_label", "term", "estimate", 
+  expect_equal(my_design %>% run_design() %>% names(), c("inquiry", "estimand", "estimator", "term", "estimate", 
                                                          "std.error", "statistic", "p.value", "conf.low", "conf.high", 
                                                          "df", "outcome"))
 
