@@ -6,8 +6,8 @@ population <- declare_population(N = 100, u = rnorm(N))
 potential_outcomes <- declare_potential_outcomes(Y_Z_0 = 0,
                                                  Y_Z_1 = 1 + u)
 inquiry <- declare_inquiry(ATE = mean(Y_Z_1 - Y_Z_0))
-sampling <- declare_sampling(legacy = FALSE, S = complete_rs(N, n = 75))
-assignment <- declare_assignment(legacy = FALSE, Z = complete_ra(N, m = 50))
+sampling <- declare_sampling(S = complete_rs(N, n = 75))
+assignment <- declare_assignment(Z = complete_ra(N, m = 50))
 reveal_Y <- declare_reveal(Y, Z)
 estimator <- declare_estimator(Y ~ Z, inquiry = inquiry)
 design <-
