@@ -11,7 +11,7 @@ test_that("Noncompliance", {
     D_Z_1 = rbinom(n = N, size = 1, prob = pnorm(noise + 1))
   )
 
-  my_assignment <- declare_assignment(legacy = FALSE, Z = complete_ra(N, m = 50))
+  my_assignment <- declare_assignment(Z = complete_ra(N, m = 50))
 
   CACE <- declare_inquiry(CACE = mean(Y_D_1[complier == 1] - Y_D_0[complier == 1]))
   ITT_d <- declare_inquiry(ITT_d = mean(complier))
@@ -59,8 +59,8 @@ test_that("Noncompliance", {
 
   diag <- diagnose_design(design, sims = 2, bootstrap_sims = FALSE)
 
-  expect_equal(diag$diagnosands$mean_inquiry[1], 2)
-  expect_equal(diag$diagnosands$estimator_label[1], "CACE_hat") 
+  expect_equal(diag$diagnosands$mean_estimand[1], 2)
+  expect_equal(diag$diagnosands$estimator[1], "CACE_hat") 
   # ITT_d is not in output - not estimated: AC: NOW IT IS!
 })
 
@@ -90,7 +90,7 @@ test_that("POs correctly assembled for noncompliance case", {
     assignment_variables = "D"
   )
 
-  assignment <- declare_assignment(legacy = FALSE, Z = complete_ra(N, prob = 0.5))
+  assignment <- declare_assignment(Z = complete_ra(N, prob = 0.5))
 
     noncompliance <-
       pop +
