@@ -2,12 +2,6 @@ context("Utilities")
 
 
 
-test_that("onLoad adds DD drat repo", {
-  expect_equal(.onLoad()["declaredesign"],
-               c(declaredesign = "https://declaredesign.github.io"))
-})
-
-
 test_that("pretty printers", {
   expect_output(print(declare_population(sleep)),
                 "declare_population\\(sleep\\)")
